@@ -6,17 +6,19 @@ import SoftLayer
 from SoftLayer.CLI import environment
 from SoftLayer.CLI import exceptions
 
+MULTIPLE = '(Multiple allowed)'
+
 
 @click.command(cls=SoftLayer.CLI.command.SLCommand, )
 @click.argument('volume_id')
 @click.option('--hardware-id', '-h', multiple=True,
-              help='The id of one SoftLayer_Hardware to authorize')
+              help='The id of one SoftLayer_Hardware to authorize ' + MULTIPLE)
 @click.option('--virtual-id', '-v', multiple=True,
-              help='The id of one SoftLayer_Virtual_Guest to authorize')
+              help='The id of one SoftLayer_Virtual_Guest to authorize ' + MULTIPLE)
 @click.option('--ip-address-id', '-i', multiple=True,
-              help='The id of one SoftLayer_Network_Subnet_IpAddress to authorize')
+              help='The id of one SoftLayer_Network_Subnet_IpAddress to authorize ' + MULTIPLE)
 @click.option('--ip-address', multiple=True,
-              help='An IP address to authorize')
+              help='An IP address to authorize ' + MULTIPLE)
 @environment.pass_env
 def cli(env, volume_id, hardware_id, virtual_id, ip_address_id, ip_address):
     """Authorizes hosts to access a given volume"""
