@@ -9,7 +9,7 @@ from SoftLayer.CLI import helpers
 from SoftLayer import utils
 
 
-@click.command()
+@click.command(cls=SoftLayer.CLI.command.SLCommand, )
 @click.argument('volume_id')
 @environment.pass_env
 def cli(env, volume_id):
@@ -110,4 +110,7 @@ def cli(env, volume_id):
             original_volume_info.add_row(['Original Snapshot Name', block_volume['originalSnapshotName']])
         table.add_row(['Original Volume Properties', original_volume_info])
 
+    notes = '{}'.format(block_volume.get('notes', ''))
+    table.add_row(['Notes', notes])
+
     env.fout(table)
