@@ -52,6 +52,7 @@ ALL_ROUTES = [
     ('virtual:capacity', 'SoftLayer.CLI.virt.capacity:cli'),
     ('virtual:placementgroup', 'SoftLayer.CLI.virt.placementgroup:cli'),
     ('virtual:migrate', 'SoftLayer.CLI.virt.migrate:cli'),
+    ('virtual:access', 'SoftLayer.CLI.virt.access:cli'),
     ('virtual:monitoring', 'SoftLayer.CLI.virt.monitoring:cli'),
 
     ('dedicatedhost', 'SoftLayer.CLI.dedicatedhost'),
@@ -125,6 +126,7 @@ ALL_ROUTES = [
     ('block:volume-limits', 'SoftLayer.CLI.block.limit:cli'),
     ('block:volume-refresh', 'SoftLayer.CLI.block.refresh:cli'),
     ('block:volume-convert', 'SoftLayer.CLI.block.convert:cli'),
+    ('block:volume-options', 'SoftLayer.CLI.block.options:cli'),
     ('block:volume-set-note', 'SoftLayer.CLI.block.set_note:cli'),
     ('block:object-list', 'SoftLayer.CLI.block.object_list:cli'),
     ('block:object-storage-detail', 'SoftLayer.CLI.block.object_storage_detail:cli'),
@@ -174,6 +176,7 @@ ALL_ROUTES = [
     ('file:volume-limits', 'SoftLayer.CLI.file.limit:cli'),
     ('file:volume-refresh', 'SoftLayer.CLI.file.refresh:cli'),
     ('file:volume-convert', 'SoftLayer.CLI.file.convert:cli'),
+    ('file:volume-options', 'SoftLayer.CLI.file.options:cli'),
     ('file:volume-set-note', 'SoftLayer.CLI.file.set_note:cli'),
 
     ('firewall', 'SoftLayer.CLI.firewall'),
@@ -210,6 +213,8 @@ ALL_ROUTES = [
     ('ipsec:translation-remove', 'SoftLayer.CLI.vpn.ipsec.translation.remove:cli'),
     ('ipsec:translation-update', 'SoftLayer.CLI.vpn.ipsec.translation.update:cli'),
     ('ipsec:update', 'SoftLayer.CLI.vpn.ipsec.update:cli'),
+    ('ipsec:order', 'SoftLayer.CLI.vpn.ipsec.order:cli'),
+    ('ipsec:cancel', 'SoftLayer.CLI.vpn.ipsec.cancel:cli'),
 
     ('loadbal', 'SoftLayer.CLI.loadbal'),
     ('loadbal:detail', 'SoftLayer.CLI.loadbal.detail:cli'),
@@ -269,7 +274,6 @@ ALL_ROUTES = [
     ('hardware:detail', 'SoftLayer.CLI.hardware.detail:cli'),
     ('hardware:billing', 'SoftLayer.CLI.hardware.billing:cli'),
     ('hardware:edit', 'SoftLayer.CLI.hardware.edit:cli'),
-    ('hardware:guests', 'SoftLayer.CLI.hardware.guests:cli'),
     ('hardware:list', 'SoftLayer.CLI.hardware.list:cli'),
     ('hardware:power-cycle', 'SoftLayer.CLI.hardware.power:power_cycle'),
     ('hardware:power-off', 'SoftLayer.CLI.hardware.power:power_off'),
@@ -330,6 +334,7 @@ ALL_ROUTES = [
     ('subnet:lookup', 'SoftLayer.CLI.subnet.lookup:cli'),
     ('subnet:edit-ip', 'SoftLayer.CLI.subnet.edit_ip:cli'),
     ('subnet:route', 'SoftLayer.CLI.subnet.route:cli'),
+    ('subnet:clear-route', 'SoftLayer.CLI.subnet.clear_route:cli'),
 
     ('tags', 'SoftLayer.CLI.tags'),
     ('tags:cleanup', 'SoftLayer.CLI.tags.cleanup:cli'),
@@ -360,8 +365,10 @@ ALL_ROUTES = [
     ('user:edit-details', 'SoftLayer.CLI.user.edit_details:cli'),
     ('user:create', 'SoftLayer.CLI.user.create:cli'),
     ('user:delete', 'SoftLayer.CLI.user.delete:cli'),
+    ('user:device-access', 'SoftLayer.CLI.user.device_access:cli'),
     ('user:vpn-manual', 'SoftLayer.CLI.user.vpn_manual:cli'),
     ('user:vpn-subnet', 'SoftLayer.CLI.user.vpn_subnet:cli'),
+    ('user:remove-access', 'SoftLayer.CLI.user.remove_access:cli'),
 
     ('vlan', 'SoftLayer.CLI.vlan'),
     ('vlan:create', 'SoftLayer.CLI.vlan.create:cli'),
@@ -379,12 +386,7 @@ ALL_ROUTES = [
 
     ('autoscale', 'SoftLayer.CLI.autoscale'),
     ('autoscale:list', 'SoftLayer.CLI.autoscale.list:cli'),
-    ('autoscale:create', 'SoftLayer.CLI.autoscale.create:cli'),
     ('autoscale:detail', 'SoftLayer.CLI.autoscale.detail:cli'),
-    ('autoscale:scale', 'SoftLayer.CLI.autoscale.scale:cli'),
-    ('autoscale:logs', 'SoftLayer.CLI.autoscale.logs:cli'),
-    ('autoscale:tag', 'SoftLayer.CLI.autoscale.tag:cli'),
-    ('autoscale:edit', 'SoftLayer.CLI.autoscale.edit:cli'),
     ('autoscale:delete', 'SoftLayer.CLI.autoscale.delete:cli'),
 ]
 
