@@ -8,7 +8,7 @@ from SoftLayer.CLI import environment
 from SoftLayer.CLI import formatting
 
 
-@click.command()
+@click.command(cls=SoftLayer.CLI.command.SLCommand, )
 @click.option('--open / --closed', 'is_open', default=True,
               help="Display only open or closed tickets")
 @environment.pass_env
@@ -16,7 +16,7 @@ def cli(env, is_open):
     """List tickets."""
     ticket_mgr = SoftLayer.TicketManager(env.client)
     table = formatting.Table([
-        'id', 'assigned_user', 'title', 'last_edited', 'status', 'updates', 'priority'
+        'id', 'Case_Number', 'assigned_user', 'title', 'last_edited', 'status', 'updates', 'priority'
     ])
 
     tickets = ticket_mgr.list_tickets(open_status=is_open, closed_status=not is_open)
@@ -27,6 +27,7 @@ def cli(env, is_open):
 
         table.add_row([
             ticket['id'],
+            ticket['serviceProviderResourceId'],
             user,
             click.wrap_text(ticket['title']),
             ticket['lastEditDate'],
